@@ -39,8 +39,8 @@ class MILOU_EXPORT Preview : public QQuickItem
     Q_PROPERTY(bool loaded READ loaded)
 
 public:
-    Preview(QQuickItem* parent = 0);
-    virtual ~Preview();
+    explicit Preview(QQuickItem* parent = nullptr);
+    ~Preview() override;
 
     QString mimetype() const;
     void setMimetype(const QString& mime);
